@@ -56,6 +56,13 @@ char *strdup(const char *src);   //Ultrix lacks it. Otherwise, we're just superf
 
 extern char *scratch;
 
+char *get_text_buffer(int chars);		// alloc with extra space for char encoding/decoding
+char *get_text_buffer(const char *string);	// realloc to current length plus extra space as above
+char *get_text_line_buffer();
+char *get_text_cmd_buffer();
+
+inline const char *never_null(const char *string) { return string ? string : ""; };
+
 FIT_IDX fit(char c);		 // converts 'f', 'i' or 't' to 0, 1 or 2, respectively
 UNIT str2enum(const char *item, const char *list, int dflt);
 const char *enum2str(int item, const char *list);
